==> localstack-ext-2.1.1.dev20230708135750.tar.gz: localstack-ext-2.1.1.dev20230708135750/localstack_ext/bootstrap/pods/remotes/api.py <==
import json
from abc import ABC,abstractmethod
from typing import Dict,List
import requests
from localstack import config
from localstack_ext.constants import API_PATH_PODS
class CloudPodsRemotesInterface(ABC):
	@abstractmethod
	def create_remote(self,name,protocols,remote_url=None):0
	@abstractmethod
	def delete_remote(self,name):0
	@abstractmethod
	def get_remote(self,name):0
	@abstractmethod
	def get_remotes(self):0
class CloudPodsRemotesClient(CloudPodsRemotesInterface):
	@property
	def endpoint(self):return f"{config.get_edge_url()}{API_PATH_PODS}/remotes"
	def create_remote(B,name,protocols,remote_url=None):
		C={'name':name,'protocols':protocols,'remote_url':remote_url};A=requests.post(url=f"{B.endpoint}/{name}",data=json.dumps(C),headers={'Content-Type':'application/json'})
		if not A.ok:raise Exception(f"Failed to create remote: {A.content}")
	def delete_remote(B,name):
		A=requests.delete(url=f"{B.endpoint}/{name}")
		if not A.ok:raise Exception(f"Failed to delete remote: {A.content}")
	def get_remotes(B):
		A=requests.get(url=f"{B.endpoint}s")
		if not A.ok:raise Exception(f"Failed to get response: {A.content}")
		C=json.loads(A.content);return C.get('remotes',[])
	def get_remote(B,name):
		A=requests.get(url=f"{B.endpoint}/{name}")
		if not A.ok:raise Exception(f"Failed to get response: {A.content}")
		C=json.loads(A.content);return C
	def get_token(B):
		A=requests.get(url=f"{B.endpoint}/token")
		if A.status_code==404:return
		if not A.ok:raise Exception(f"Failed to get response: {A.content}")
		C=json.loads(A.content);return C.get('token')

==> localstack-ext-2.2.1.dev20230808110233.tar.gz: localstack-ext-2.2.1.dev20230808110233/localstack_ext/bootstrap/pods/remotes/api.py <==
import json
from abc import ABC,abstractmethod
from typing import Dict,List
import requests
from localstack import config
from localstack_ext.constants import API_PATH_PODS
class CloudPodsRemotesInterface(ABC):
	@abstractmethod
	def create_remote(self,name,protocols,remote_url=None):0
	@abstractmethod
	def delete_remote(self,name):0
	@abstractmethod
	def get_remote(self,name):0
	@abstractmethod
	def get_remotes(self):0
class CloudPodsRemotesClient(CloudPodsRemotesInterface):
	@property
	def endpoint(self):return f"{config.get_edge_url()}{API_PATH_PODS}/remotes"
	def create_remote(B,name,protocols,remote_url=None):
		C={'name':name,'protocols':protocols,'remote_url':remote_url};A=requests.post(url=f"{B.endpoint}/{name}",data=json.dumps(C),headers={'Content-Type':'application/json'})
		if not A.ok:raise Exception(f"Failed to create remote: {A.content}")
	def delete_remote(B,name):
		A=requests.delete(url=f"{B.endpoint}/{name}")
		if not A.ok:raise Exception(f"Failed to delete remote: {A.content}")
	def get_remotes(B):
		A=requests.get(url=B.endpoint)
		if not A.ok:raise Exception(f"Failed to get list of remotes: {A.content}")
		C=json.loads(A.content);return C.get('remotes',[])
	def get_remote(B,name):
		A=requests.get(url=f"{B.endpoint}/{name}")
		if not A.ok:raise Exception(f"Failed to get remote: {A.content}")
		C=json.loads(A.content);return C
	def get_token(B):
		A=requests.get(url=f"{B.endpoint}/token")
		if A.status_code==404:return
		if not A.ok:raise Exception(f"Failed to get token: {A.content}")
		C=json.loads(A.content);return C.get('token')
